VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "JukePlugin"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
Attribute VB_Ext_KEY = "SavedWithClassBuilder6" ,"Yes"
Attribute VB_Ext_KEY = "Top_Level" ,"Yes"
Option Explicit

' *********************************************************
' VB6 Jukebox Plugin System Host
' Author: Ben Baker (aka HeadKaze)
' *********************************************************

Private Type PluginInfoType
    Name As String
    Author As String
    Version As String
    Description As String
End Type

Public Enum AttractModeType
    OnActive
    OnNotActive
    Off
End Enum

Public Enum LoopType
    OnOnce
    OnAlways
    Off
End Enum

Public Enum BoolType
    TrueFalse
    EnableDisable
End Enum

Private pDC As Long
Private hDll As Long

Private pInitialize As Long
Private pShutdown As Long
Private pGetPluginInfo As Long
Private pConfigure As Long
Private pCommand As Long

Private PluginInfo As PluginInfoType

Public Function Initialize(hDC As Long, PluginName As String) As Long
    Dim RetVal As Long
    
    pDC = hDC
    hDll = LoadLibrary(PluginName)
    
    If hDll = 0 Then
        Initialize = 0
        Exit Function
    End If
       
    pGetPluginInfo = GetProcAddress(hDll, "Juke_GetPluginInfo")
    
    If IsPlugin Then
        pInitialize = GetProcAddress(hDll, "Juke_Initialize")
        pShutdown = GetProcAddress(hDll, "Juke_Shutdown")
        pConfigure = GetProcAddress(hDll, "Juke_Configure")
        pCommand = GetProcAddress(hDll, "Juke_Command")
        
        If pGetPluginInfo <> 0 Then
            Dim sPluginInfo As String
            Dim sArray() As String
            
            sPluginInfo = PtrToVBString(CallFuncPtr(pDC, pGetPluginInfo, vbNullString))
                       
            sArray = Split(sPluginInfo, "|")
                  
            If UBound(sArray, 1) + 1 = 4 Then
                PluginInfo.Name = sArray(0)
                PluginInfo.Author = sArray(1)
                PluginInfo.Version = sArray(2)
                PluginInfo.Description = sArray(3)
            End If
        End If
        
        If pInitialize <> 0 Then
            RetVal = CallFuncPtr(pDC, pInitialize, vbNullString)
        End If
    Else
        RetVal = 0
        Shutdown
    End If
    
    Initialize = RetVal
End Function

Public Function Shutdown() As Long
    Dim RetVal As Long
       
    If pShutdown <> 0 Then
        RetVal = CallFuncPtr(pDC, pShutdown, vbNullString)
    End If
       
    If hDll <> 0 Then
        FreeLibrary hDll
    End If
    
    pGetPluginInfo = 0
    pInitialize = 0
    pShutdown = 0
    pConfigure = 0
    pCommand = 0
    
    Shutdown = RetVal
End Function

Public Function Configure(hwnd As Long) As Long
    Dim RetVal As Long
    If pConfigure <> 0 Then
        RetVal = CallFuncPtr(pDC, pConfigure, hwnd)
    End If
    Configure = RetVal
End Function

Public Function Command(Name As String, ParamArray Params() As Variant) As String()
    Dim sCommand As String
    Dim sArray() As String
    Dim sParams As String
    Dim I As Integer
    
    For I = 0 To UBound(Params)
        sParams = sParams & Params(I)
        If I < UBound(Params) Then
            sParams = sParams & "|"
        End If
    Next
    
    If pCommand <> 0 Then
        sCommand = PtrToVBString(CallFuncPtr(pDC, pCommand, Name, sParams))
        sArray = Split(sCommand, "|")
    End If
    Command = sArray
End Function

Public Function PluginEventCreate(Name As String, ValueStr As String) As String()
    PluginEventCreate = Command("JUKE_PLUGIN_EVENT_CREATE", Name, ValueStr)
End Function

Public Function PluginEventSend(Name As String, ValueStr As String) As String()
    PluginEventSend = Command("JUKE_PLUGIN_EVENT_SEND", Name, ValueStr)
End Function

Public Function PluginEventGet() As String()
    PluginEventGet = Command("JUKE_PLUGIN_EVENT_GET", vbNullString)
End Function

Public Function AppGainFocus() As String()
    AppGainFocus = Command("JUKE_APP_GAINFOCUS", vbNullString)
End Function

Public Function AppLostFocus() As String()
    AppLostFocus = Command("JUKE_APP_LOSTFOCUS", vbNullString)
End Function

Public Function AppRestored() As String()
    AppRestored = Command("JUKE_APP_RESTORED", vbNullString)
End Function

Public Function AppMinimized() As String()
    AppMinimized = Command("JUKE_APP_MINIMIZED", vbNullString)
End Function

Public Function AppUnicode(Value As Boolean) As String()
    AppUnicode = Command("JUKE_APP_UNICODE", BoolToString(Value, BoolType.TrueFalse))
End Function

Public Function AppHost(Name As String) As String()
    AppHost = Command("JUKE_APP_HOST", Name)
End Function

Public Function SongListAddSong(System As String, Position As String, Title As String, Artist As String, Album As String, Genre As String, TotalDuration As String, TrackNum As String, AlbumNum As String, More As String) As String()
    SongListAddSong = Command("JUKE_SONGLIST_ADD_SONG", System, Position, Title, Artist, Album, Genre, TotalDuration, TrackNum, AlbumNum, More)
End Function

Public Function SongListRemoveSong(Position As Integer) As String()
    SongListRemoveSong = Command("JUKE_SONGLIST_REMOVE_SONG", Position)
End Function

Public Function SongListMoveSong(OldPosition As Integer, NewPosition As Integer) As String()
    SongListMoveSong = Command("JUKE_SONGLIST_MOVE_SONG", OldPosition, NewPosition)
End Function

Public Function SongListClear() As String()
    SongListClear = Command("JUKE_SONGLIST_CLEAR", vbNullString)
End Function

Public Function SongListCurrentPosition(Position As Integer) As String()
    SongListCurrentPosition = Command("JUKE_SONGLIST_CURRENTPOSITION", Position)
End Function

Public Function SongListSuggeston() As String()
    SongListSuggeston = Command("JUKE_SONGLIST_SUGGESTION", vbNullString)
End Function

Public Function SongStart(System As String, Title As String, Artist As String, Album As String, Genre As String, TotalDuration As String, TrackNum As String, AlbumNum As String) As String()
    SongStart = Command("JUKE_SONG_START", System, Title, Artist, Album, Genre, TotalDuration, TrackNum, AlbumNum)
End Function

Public Function SongNext(System As String, Title As String, Artist As String, Album As String, Genre As String, TotalDuration As String, TrackNum As String, AlbumNum As String) As String()
    SongNext = Command("JUKE_SONG_START", System, Title, Artist, Album, Genre, TotalDuration, TrackNum, AlbumNum)
End Function

Public Function SongFinish() As String()
    SongFinish = Command("JUKE_SONG_FINISH", vbNullString)
End Function

Public Function SongRestart() As String()
    SongRestart = Command("JUKE_SONG_RESTART", vbNullString)
End Function

Public Function SongSkip() As String()
    SongSkip = Command("JUKE_SONG_SKIP", vbNullString)
End Function

Public Function SongPause() As String()
    SongPause = Command("JUKE_SONG_PAUSE", vbNullString)
End Function

Public Function SongResume() As String()
    SongResume = Command("JUKE_SONG_RESUME", vbNullString)
End Function

Public Function SongFastFwdStart() As String()
    SongFastFwdStart = Command("JUKE_SONG_FASTFWD_START", vbNullString)
End Function

Public Function SongFastFwdFinish() As String()
    SongFastFwdFinish = Command("JUKE_SONG_FASTFWD_FINISH", vbNullString)
End Function

Public Function SongFastRevStart() As String()
    SongFastRevStart = Command("JUKE_SONG_FASTREV_START", vbNullString)
End Function

Public Function SongFastRevFinish() As String()
    SongFastRevFinish = Command("JUKE_SONG_FASTREV_FINISH", vbNullString)
End Function

Public Function SongPlayPosition(CurPosSecs As Integer, TotalDuration As Integer) As String()
    SongPlayPosition = Command("JUKE_SONG_PLAY_POSITION", CurPosSecs, TotalDuration)
End Function

Public Function EnterAlbumValue(Value As String) As String()
    EnterAlbumValue = Command("JUKE_ENTER_ALBUM_VALUE", Value)
End Function

Public Function EnterTrackValue(Value As String) As String()
    EnterTrackValue = Command("JUKE_ENTER_TRACK_VALUE", Value)
End Function

Public Function VolumeChange(System As String, CurVolumeLevel As Integer, MinVolumeLevel As Integer, MaxVolumeLevel As Integer) As String()
    VolumeChange = Command("JUKE_VOLUME_CHANGE", System, CurVolumeLevel, MinVolumeLevel, MaxVolumeLevel)
End Function

Public Function VolumeMute(Value As Boolean) As String()
    VolumeMute = Command("JUKE_VOLUME_MUTE", BoolToString(Value, BoolType.TrueFalse))
End Function

Private Function AttractModeToString(Value As AttractModeType) As String
    Dim sValue As String
    
    Select Case Value
        Case AttractModeType.OnActive
            sValue = "ONACTIVE"
        Case AttractModeType.OnNotActive
            sValue = "ONNOTACTIVE"
        Case AttractModeType.Off
            sValue = "OFF"
    End Select
    
    AttractModeToString = sValue
End Function

Private Function LoopToString(Value As LoopType) As String
    Dim sValue As String
    
    Select Case Value
        Case LoopType.OnOnce
            sValue = "ONONCE"
        Case LoopType.OnAlways
            sValue = "ONALWAYS"
        Case LoopType.Off
            sValue = "OFF"
    End Select
    
    LoopToString = sValue
End Function

Private Function BoolToString(Value As Boolean, bType As BoolType) As String
    Dim sValue As String
    
    If bType = TrueFalse Then
        If Value Then
            sValue = "TRUE"
        Else
            sValue = "FALSE"
        End If
    Else
        If Value Then
            sValue = "ENABLE"
        Else
            sValue = "DISABLE"
        End If
    End If
    
    BoolToString = sValue
End Function

Public Property Get IsPlugin() As Boolean
    IsPlugin = (pGetPluginInfo <> 0)
End Property

Public Property Get Name() As String
   Name = PluginInfo.Name
End Property

Public Property Get Author() As String
   Author = PluginInfo.Author
End Property

Public Property Get Version() As String
   Version = PluginInfo.Version
End Property

Public Property Get Description() As String
   Description = PluginInfo.Description
End Property

